@@ -506,7 +506,7 @@ test -x $netassist_prog && netassist_entry=$(entry \
     $"Network Troubleshooting")
 
 
-repomanager_prog=/usr/sbin/repo-manager
+repomanager_prog=/usr/bin/repo-manager
 test -x $repomanager_prog && repomanager_entry=$(entry \
     $ICONS/repo-manager.png \
     "su-to-root -X -c repo-manager &" \
